"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestError = void 0;
const axios_1 = __importDefault(require("axios"));
const defaultRequest = (config) => __awaiter(void 0, void 0, void 0, function* () {
    const { url, method, headers, params, data } = config;
    try {
        const response = yield axios_1.default({
            url,
            method: method,
            headers,
            params,
            data,
        });
        return {
            data: response.data,
            status: response.status,
            statusText: response.statusText,
            headers: response.headers,
            config: config,
        };
    }
    catch (e) {
        let response;
        if (e.response) {
            response = {
                data: e.response.data,
                status: e.response.status,
                statusText: e.response.statusText,
                headers: e.response.headers,
                config: config,
            };
        }
        throw new RequestError(e.message, config, response);
    }
});
class RequestError extends Error {
    constructor(message, config, response) {
        super(message);
        this.isRequestError = true;
        this.response = response;
        this.config = config;
    }
}
exports.RequestError = RequestError;
exports.default = defaultRequest;
